@@ -86,10 +86,16 @@ class AB_Base:
             # I didn't get an ID
             if self.kwargs.get("uid", None) is not None or \
                     self.kwargs.get("search_name", None) is not None or \
-                    self.kwargs.get( "search_complex", None) is not None:
+                    self.kwargs.get("search_complex", None) is not None:
 
                 # I searched for and found (or not) a result
-                self.id = self.search()
+                self.logger.debug("Doing a Search")
+                try:
+                    self.id = self.search()
+                except Exception as error_in_search:
+                    self.logger.debug(error_in_search)
+                    raise error_in_search
+
 
                 self.init_action_taken = "read"
 
